@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -20,6 +20,7 @@ use parent qw(Kernel::System::SysConfig::BaseValueType);
 our @ObjectDependencies = (
     'Kernel::Language',
     'Kernel::Output::HTML::Layout',
+    'Kernel::System::DateTime',
     'Kernel::System::Log',
 );
 
@@ -299,7 +300,7 @@ Extracts the effective value from a XML parsed setting.
             ...
         },
         DefaultValue   => 'Product 5',      # (optional)
-        Class          => 'My class'        # (optional)
+        Class          => 'My class',       # (optional)
         Item           => [                 # (optional) XML parsed item
             {
                 'ValueType' => 'VacationDaysOneTime',
@@ -442,7 +443,7 @@ sub SettingRender {
                 if ( $Param{RW} ) {
                     $HTML .= "<button class='RemoveButton' type='button' "
                         . "title='$RemoveThisEntry' value='Remove this entry'>\n"
-                        . "    <i class='fa fa-minus-circle'></i>\n"
+                        . "    <i class='fa fa-minus-square-o'></i>\n"
                         . "    <span class='InvisibleText'>$RemoveThisEntry</span>\n"
                         . "</button>\n";
                 }
